import GamefieldPointer from "./GamefieldPointer"
import HitElems from "./HitElems"
import Ship from "./Ship"
import { useGameProps } from "@hooks/useGameProps"
import useShips from "@hooks/useShips"
import {
  composeTargetTiles,
  intersectingShip,
  shipProps,
} from "@lib/utils/helpers"

function Targets() {
  const { payload, target, targetPreview, mode, hits } = useGameProps()
  const { ships } = useShips()

  if (payload?.game?.state === "running")
    return (
      <>
        {[
          ...composeTargetTiles(target, mode, hits).map((props, i) => (
            <GamefieldPointer key={"t" + i} props={props} />
          )),
          ...composeTargetTiles(targetPreview, mode, hits).map((props, i) => (
            <GamefieldPointer key={"p" + i} props={props} preview />
          )),
        ]}
      </>
    )

  if (payload?.game?.state === "starting" && mode >= 0 && targetPreview.show) {
    const ship = shipProps(ships, mode, targetPreview)
    const { fields, borders, score } = intersectingShip(ships, ship)
    return (
      <>
        <Ship
          preview
          warn={score > 0}
          color={fields.length ? "red" : borders.length ? "orange" : undefined}
          key={targetPreview.orientation}
          props={ship}
        />
        <HitElems
          props={{
            hits: fields.map((e, i) => ({ ...e, i, hit: true })),
          }}
        />
        <HitElems
          props={{
            hits: borders.map((e, i) => ({ ...e, i, hit: true })),
            colorOverride: "orange",
          }}
        />
      </>
    )
  }

  return <></>
}

export default Targets
