import { ShipProps } from "../interfaces/frontend"
import { useGameProps } from "./useGameProps"
import { useSession } from "next-auth/react"
import { useCallback, useMemo } from "react"

function useShips() {
  const gameProps = useGameProps()
  const { data: session } = useSession()

  const ships = useMemo(
    () =>
      gameProps.payload?.users.find((e) => e?.id === session?.user.id)?.ships ??
      [],
    [gameProps.payload?.users, session?.user.id]
  )
  const setShips = useCallback(
    (ships: ShipProps[]) => gameProps.setShips(ships, session?.user.id ?? ""),
    [gameProps, session?.user.id]
  )
  const removeShip = useCallback(
    (ship: ShipProps) => gameProps.removeShip(ship, session?.user.id ?? ""),
    [gameProps, session?.user.id]
  )

  return { ships, setShips, removeShip }
}

export default useShips
